! SPT lensing driver, written by S. Feeney

program spt_lensing_test

  use spt_lensing_likelihood
  
  integer, parameter :: l_max_spt_lens = 1500
  integer :: l, dummy_i, n_args
  real(8), dimension(2: l_max_spt_lens) :: c_l_pp
  real(8) :: ln_like_spt_lens, dummy_r
  character(len = 255) :: c_l_file
  
  
  ! check for user-specified filename
  n_args = iargc()
  if (n_args .gt. 0) then
     
     call getarg(1, c_l_file)
     
  else
     
     c_l_file = 'wmap7_lcdm_sz_lens_scalar_cl.dat'
     
  end if
  print*, 'processing file: ' // trim(adjustl(c_l_file))
  
  
  ! read in a theoretical lensing power spectrum from file and convert
  ! to the correct units. the power spectrum output to file by CAMB is
  ! l^4 C_l^{phiphi} * T_CMB^2, so need to divide by T_CMB^2 and 10^-7
  ! to get a dimensionless power spectrum at the scale wanted by SPT.
  c_l_pp(:) = 0.d0
  call get_free_lun(lun)
  open(unit = lun, file = c_l_file, form = 'formatted', &
       status = 'old', action = 'read')
  do l = 2, l_max_spt_lens
     
     read (lun, '(2X, I4, 5(X, E14.05))') &
                 dummy_i, dummy_r, dummy_r, dummy_r, c_l_pp(l), &
                 dummy_r
     c_l_pp(l) = c_l_pp(l) / (2.725d6) ** 2 / (1.0d-7)
     
  enddo
  close(lun)
  
  
  ! note that CosmoMC uses C_l^{dd}, not C_l^{phiphi}. in order to 
  ! correctly normalize the C_ls from CosmoMC we'll need to pass on
  ! 2 * pi * (l / (l + 1)) ^ 2 C_l^{dd} / (1.0d-7), taking care to 
  ! check whether the C_ls are dimensionless (they have the correct 
  ! dimensions by default)
  
  
  ! initialise the SPT likelihood and compute!
  call spt_likelens_init
  call spt_likelens_compute(c_l_pp, ln_like_spt_lens)
  write(*, *) 'SPT lens -2 ln(like) = ', -2.d0 * ln_like_spt_lens
  
  
end program spt_lensing_test
